export libdir="$(builtin cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"

. $libdir/../../rpkglib/preproc/lib.sh
  
function die {
    echo fail.
    exit 1
}

function log_filter {
    grep -Ev -e '^> (env|cwd):' -e 'Wrote: /tmp/' -e 'git_(dir_|cwd_)?archive: archiving /tmp/'\
    -e 'git_(dir_|cwd_)?pack: packing path /tmp/' -e 'fatal: [nN]ot a git repository' -e '(GIT_DISCOVERY_ACROSS_FILESYSTEM not set)'\
    -e '^Date:' -e '^commit '
}

function run {
    echo '>' $@;
    eval $@;
}

function wtree_sub {
    latest_ctime="$(builtin cd "$1"; encode_decimal $(git_latest_ctime))"
    sed -Ei "s/\.wtree\.[a-zA-Z0-9]+/.wtree.$latest_ctime/" "$2"
}

function head_commit_sub {
    full_hash=$(git -C "$1" rev-parse HEAD)
    short_hash=$(git -C "$1" rev-parse --short HEAD)
    sed -Ei -e "s|(\.git\.[0-9]+)\.[a-zA-Z0-9]+|\1.$short_hash|" -e "s|#\w{40}:|#$full_hash:|" "$2"
}

function prepare_input {
    cat "$1" | sed -Ee 's|^(.+) ::$|\1:\n{{{ \1 }}}\n|' | sed -Ee 's|^(.+) :$|\1:\n{{{ \1 }}}|' | sed -Ee 's|^(.*[^:}])$|\1: {{{ \1 }}}|' > "$2"
}

function generic_test {
    declare opts= path= input= expected_output= expected_log= custom_test= copy_only= "$@"

    local out="$(mktemp -d)"

    run "${PYTHON:-/usr/bin/python3}" "../preproc.py --path $path --input $input --output $out/output $opts | log_filter &> $out/log"

    if [ -n "$copy_only" ]; then
        cp "$out/log" "$out/output" .
        echo copied.
        rm -r "$out"
        exit
    fi

    run "diff $expected_output $out/output || die"
    run "diff $expected_log $out/log || die"
    run "$custom_test out=$out || die"

    rm -r "$out"
    echo success.
}
