#!/bin/bash

. ../lib.sh

repo=`mktemp -d`
output=`mktemp`

mkdir $repo/subdir1 $repo/subdir2 $repo/subdir3
prepare_input input $repo/subdir2/input
echo 1 > $repo/subdir1/cookie
echo 2 > $repo/subdir3/cookie
echo 3 > $repo/subdir2/cookie

git init $repo
git -C $repo config user.email "clime@redhat.com"
git -C $repo config user.name "clime"
git -C $repo remote add origin https://pagure.io/clime/test.git
git -C $repo add -A
git -C $repo commit -m 'commit 1'
git -C $repo tag -a -m 'tag message' test-0.4-1
git -C $repo tag -a -m 'tag message' test-subdir1-0.4-1
git -C $repo tag -a -m 'tag message' test-subdir2-0.4-1
git -C $repo tag -a -m 'tag message' test-subdir3-0.4-1

touch output && cp output $output

function custom_test {
    declare out= "$@"
    run "tar -C $out -xf $out/foo_dir_nodirname.tar.gz || die"
    run "diff $out/test-subdir2-0.4/cookie $repo/subdir2/cookie || die"

    run "tar -C $out -xf $out/bar_dir_nodirname.tar.gz || die"
    run "diff $out/test-subdir2-0.4/cookie $repo/subdir2/cookie || die"

    run "tar -C $out -xf $out/foo_dir.tar.gz || die"
    run "diff $out/foo_dir/cookie $repo/subdir2/cookie || die"

    run "tar -C $out -xf $out/bar_dir.tar.gz || die"
    run "diff $out/bar_dir/cookie $repo/subdir2/cookie || die"

    run "tar -C $out -xf $out/foo_cwd_nodirname.tar.gz || die"
    run "diff $out/test-subdir1-0.4/cookie $repo/subdir1/cookie || die"

    run "tar -C $out -xf $out/bar_cwd_nodirname.tar.gz || die"
    run "diff $out/test-subdir1-0.4/cookie $repo/subdir1/cookie || die"

    run "tar -C $out -xf $out/foo_cwd.tar.gz || die"
    run "diff $out/foo_cwd/cookie $repo/subdir1/cookie || die"

    run "tar -C $out -xf $out/bar_cwd.tar.gz || die"
    run "diff $out/bar_cwd/cookie $repo/subdir1/cookie || die"

    run "tar -C $out -xf $out/subdir3_foo_nodirname.tar.gz || die"
    run "diff $out/test-0.4/cookie $repo/subdir3/cookie || die"

    run "tar -C $out -xf $out/subdir3_foo_nodirname.tar.gz || die"
    run "diff $out/test-0.4/cookie $repo/subdir3/cookie || die"

    run "tar -C $out -xf $out/subdir3_foo.tar.gz || die"
    run "diff $out/subdir3_foo/cookie $repo/subdir3/cookie || die"

    run "tar -C $out -xf $out/subdir3_bar.tar.gz || die"
    run "diff $out/subdir3_bar/cookie $repo/subdir3/cookie || die"
}

generic_test opts='' path=$repo/subdir1 input=$repo/subdir2/input expected_output=$output expected_log=log custom_test=custom_test copy_only=$1

rm -rf $repo
rm $output
